==> haskell-postgresql-binary-0.12.1-32-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-postgresql-binary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgresql-binary
version: 0.12.1
id: postgresql-binary-0.12.1-DuM7uCa68BsL5OUDy56vid
key: postgresql-binary-0.12.1-DuM7uCa68BsL5OUDy56vid
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/postgresql-binary
synopsis: Encoders and decoders for the PostgreSQL'\''s binary format
description:
    An API for dealing with PostgreSQL'\''s binary data format.
    .
    It can be used to implement performant bindings to Postgres.
    E.g., <http://hackage.haskell.org/package/hasql "hasql">
    is based on this library.
    .
    It supports all Postgres versions starting from 8.3
    and is tested against 8.3, 9.3 and 9.5
    with the @integer_datetimes@ setting off and on.
category: PostgreSQL, Database, Codecs, Parsing
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    PostgreSQL.Binary.Data PostgreSQL.Binary.Decoding
    PostgreSQL.Binary.Encoding
hidden-modules: PostgreSQL.Binary.Encoding.Builders
                PostgreSQL.Binary.Prelude PostgreSQL.Binary.Integral
                PostgreSQL.Binary.Interval PostgreSQL.Binary.Numeric
                PostgreSQL.Binary.Time PostgreSQL.Binary.Inet
                PostgreSQL.Binary.BuilderPrim
abi: 71d038ea1de8611835602cf78cfa08f4
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/postgresql-binary-0.12.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/postgresql-binary-0.12.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/postgresql-binary-0.12.1
hs-libraries: HSpostgresql-binary-0.12.1-DuM7uCa68BsL5OUDy56vid
depends:
    binary-parser-0.5.5-FewhXIdNBryDruj90WPlXn
    bytestring-strict-builder-0.4.5-5MXDX8KK6On2ooOaqK4WY5
    aeson-1.2.1.0-4B0AgiChYBfAqHGTNuDPfn
    uuid-1.3.13-G8e2IZ9f5MADgTIArYC2VF time-1.8.0.2
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q bytestring-0.10.8.2
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    network-ip-0.3.0.2-FgCIMadcpT25twK322rzp
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    containers-0.5.10.2 loch-th-0.2.1-IIgFwtWU9raKenANuYCBxM
    placeholders-0.1-AcMEEx4Dnjq6E1aKP18QcK transformers-0.5.2.0
    base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT base-4.10.0.0
abi-depends: binary-parser-0.5.5-FewhXIdNBryDruj90WPlXn=48cfbfe5e650c2ad7e50591ea18ebcb8
             bytestring-strict-builder-0.4.5-5MXDX8KK6On2ooOaqK4WY5=d40d187de644610e0e6c5a7aac48c036
             aeson-1.2.1.0-4B0AgiChYBfAqHGTNuDPfn=de27a328e189bca785104a080be3af69
             uuid-1.3.13-G8e2IZ9f5MADgTIArYC2VF=ca800736034a74d62d74760fd850acfc
             time-1.8.0.2=e9c7416c5b79f57513fe11898c3d9f95
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=4e1885ea3bd9d96a68a990bad22946fe
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=23f6c0fe109d2ea8c2d28bae9257ae6c
             network-ip-0.3.0.2-FgCIMadcpT25twK322rzp=6c46969fc6df637308bd49e3f7671e2d
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=f561664cdb04511e569f0d44c9086d8e
             containers-0.5.10.2=dd4e66fa9ac268f47a15786f1100b042
             loch-th-0.2.1-IIgFwtWU9raKenANuYCBxM=18ff74c9d54855329085d5d1b2ddc72f
             placeholders-0.1-AcMEEx4Dnjq6E1aKP18QcK=ab5eb14aea61de13ab91be5e237b0ba7
             transformers-0.5.2.0=2645d250dd615ce454f807270041c5ea
             base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT=b90da37ac42a33b96ab023921895831f
             base-4.10.0.0=835a16347ec1b210054efd02671c29ee
haddock-interfaces: /usr/share/doc/haskell-postgresql-binary/html/postgresql-binary.haddock
haddock-html: /usr/share/doc/haskell-postgresql-binary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-postgresql-binary-0.12.1-33-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-postgresql-binary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgresql-binary
version: 0.12.1
id: postgresql-binary-0.12.1-3A3PoXsKXyfLnIpxcIAw5F
key: postgresql-binary-0.12.1-3A3PoXsKXyfLnIpxcIAw5F
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/postgresql-binary
synopsis: Encoders and decoders for the PostgreSQL'\''s binary format
description:
    An API for dealing with PostgreSQL'\''s binary data format.
    .
    It can be used to implement performant bindings to Postgres.
    E.g., <http://hackage.haskell.org/package/hasql "hasql">
    is based on this library.
    .
    It supports all Postgres versions starting from 8.3
    and is tested against 8.3, 9.3 and 9.5
    with the @integer_datetimes@ setting off and on.
category: PostgreSQL, Database, Codecs, Parsing
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    PostgreSQL.Binary.Data PostgreSQL.Binary.Decoding
    PostgreSQL.Binary.Encoding
hidden-modules: PostgreSQL.Binary.Encoding.Builders
                PostgreSQL.Binary.Prelude PostgreSQL.Binary.Integral
                PostgreSQL.Binary.Interval PostgreSQL.Binary.Numeric
                PostgreSQL.Binary.Time PostgreSQL.Binary.Inet
                PostgreSQL.Binary.BuilderPrim
abi: e666c1c13c564fe89a368030ccf109e2
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/postgresql-binary-0.12.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/postgresql-binary-0.12.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/postgresql-binary-0.12.1
hs-libraries: HSpostgresql-binary-0.12.1-3A3PoXsKXyfLnIpxcIAw5F
depends:
    binary-parser-0.5.5-FewhXIdNBryDruj90WPlXn
    bytestring-strict-builder-0.4.5-5MXDX8KK6On2ooOaqK4WY5
    aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y
    uuid-1.3.13-G8e2IZ9f5MADgTIArYC2VF time-1.8.0.2
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q bytestring-0.10.8.2
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    network-ip-0.3.0.2-FgCIMadcpT25twK322rzp
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    containers-0.5.10.2 loch-th-0.2.1-IIgFwtWU9raKenANuYCBxM
    placeholders-0.1-AcMEEx4Dnjq6E1aKP18QcK transformers-0.5.2.0
    base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT base-4.10.0.0
abi-depends: binary-parser-0.5.5-FewhXIdNBryDruj90WPlXn=48cfbfe5e650c2ad7e50591ea18ebcb8
             bytestring-strict-builder-0.4.5-5MXDX8KK6On2ooOaqK4WY5=d40d187de644610e0e6c5a7aac48c036
             aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=5e6b7bed78b23d60beb18bffc251a955
             uuid-1.3.13-G8e2IZ9f5MADgTIArYC2VF=ca800736034a74d62d74760fd850acfc
             time-1.8.0.2=e9c7416c5b79f57513fe11898c3d9f95
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=4e1885ea3bd9d96a68a990bad22946fe
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=23f6c0fe109d2ea8c2d28bae9257ae6c
             network-ip-0.3.0.2-FgCIMadcpT25twK322rzp=6c46969fc6df637308bd49e3f7671e2d
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=f561664cdb04511e569f0d44c9086d8e
             containers-0.5.10.2=dd4e66fa9ac268f47a15786f1100b042
             loch-th-0.2.1-IIgFwtWU9raKenANuYCBxM=18ff74c9d54855329085d5d1b2ddc72f
             placeholders-0.1-AcMEEx4Dnjq6E1aKP18QcK=ab5eb14aea61de13ab91be5e237b0ba7
             transformers-0.5.2.0=2645d250dd615ce454f807270041c5ea
             base-prelude-1.2.0.1-GfnST6wywTP6rNqw8BISGT=b90da37ac42a33b96ab023921895831f
             base-4.10.0.0=835a16347ec1b210054efd02671c29ee
haddock-interfaces: /usr/share/doc/haskell-postgresql-binary/html/postgresql-binary.haddock
haddock-html: /usr/share/doc/haskell-postgresql-binary/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
